import os
import click

from distutils.dir_util import copy_tree


@click.group()
def cli():
    pass


@cli.command()
@click.argument('botname', type=str)
def newbot(botname):
    project_dir = os.path.join(os.getcwd(), botname)
    if not os.path.isdir(project_dir):
        copy_tree(
            os.path.join(os.path.abspath(os.path.dirname(__file__)), 'project'),
            os.path.join(os.getcwd(), botname)
        )
    else:
        print(f'the {botname} directory is exist!')

def main():
    cli()

if __name__ == "__main__":
    main()



import telegram
from telegram import KeyboardButton, InlineKeyboardButton, ReplyKeyboardRemove


def build_menu(buttons, n_cols, header_buttons=[], footer_buttons=[]):
    return header_buttons + [buttons[i:i + n_cols] for i in range(0, len(buttons), n_cols)] + footer_buttons


class Page:

    def __init__(self, text, botton_list=[], header_buttons=[], footer_buttons=[], n_cols=2):
        self.text = text
        self.botton_list = botton_list
        self.header_buttons = header_buttons
        self.footer_buttons = footer_buttons
        self.n_cols = n_cols

    @property
    def markup(self):

        full_list = self.botton_list + self.header_buttons + self.footer_buttons
        menu = build_menu(self.botton_list, self.n_cols, self.header_buttons, self.footer_buttons)

        if full_list == []:
            return None

        if all([isinstance(i, KeyboardButton) for i in full_list]):
            return telegram.ReplyKeyboardMarkup(menu)
        elif all([isinstance(i, InlineKeyboardButton) for i in full_list]):
            return telegram.InlineKeyboardMarkup(menu)
        else:
            raise ValueError('there is more than one types of buttons!')

    @property
    def text_remove_keyboard(self):
        return {
            'text': self.text,
            'reply_markup': ReplyKeyboardRemove()
        }

    @property
    def caption_remove_keyboard(self):
        return {
            'text': self.text,
            'reply_markup': ReplyKeyboardRemove()
        }

    @property
    def text_markup(self):
        return {
            'text': self.text,
            'reply_markup': self.markup
        }

    @property
    def caption_markup(self):
        return {
            'caption': self.text,
            'reply_markup': self.markup
        }



import json

from pprint import pprint
from functools import wraps

from telegram import ChatAction


def send_action(action):
    """Sends `action` while processing func command."""

    def decorator(func):
        @wraps(func)
        def command_func(bot, update, *args, **kwargs):
            bot.send_chat_action(chat_id=update.effective_message.chat_id, action=action)

            return func(bot, update, *args, **kwargs)

        return command_func

    return decorator


def debug(func):
    @wraps(func)
    def wrapped(bot, update, *args, **kwargs):
        print(update)
        return func(bot, update, *args, **kwargs)

    return wrapped


send_typing_action = send_action(ChatAction.TYPING)
send_upload_video_action = send_action(ChatAction.UPLOAD_VIDEO)
send_upload_photo_action = send_action(ChatAction.UPLOAD_PHOTO)



import os.path
from setuptools import setup

# The directory containing this file
HERE = os.path.abspath(os.path.dirname(__file__))
print(HERE)

with open(os.path.join(HERE, "README.md")) as fid:
    README = fid.read()

with open(os.path.join(HERE, "requirements.txt")) as fid:
    REQUIREMENTS = fid.read().split()

# This call to setup() does all the work
setup(
    name="telekey",
    version="0.1.5",
    description="An Easy way to develop telegram bots",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/danialkeimasi/telekey",
    author="Danial Keimasi",
    author_email="danialkeimasi@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
    ],
    packages=["telekey"],
    include_package_data=True,
    install_requires=REQUIREMENTS,
    entry_points={"console_scripts": ["telekey=telekey.__main__:main"]},
)
